Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(254)

Unified Diff: third_party/WebKit/Source/core/dom/Document.h

Issue 1896793002: Rename (updateLayout/updateStyle).*.() to updateStyleAndLayout.*.() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/Document.h
diff --git a/third_party/WebKit/Source/core/dom/Document.h b/third_party/WebKit/Source/core/dom/Document.h
index 43ed093dbc516aaf3c216bd60c42fe9ce8952af6..845c77980b8c201715196543d37f4217b4d4d6f4 100644
--- a/third_party/WebKit/Source/core/dom/Document.h
+++ b/third_party/WebKit/Source/core/dom/Document.h
@@ -419,18 +419,18 @@ public:
bool needsLayoutTreeUpdateForNode(const Node&) const;
// Update ComputedStyles and attach LayoutObjects if necessary, but don't
// lay out.
- void updateLayoutTree();
- // Same as updateLayoutTree() except ignoring pending stylesheets.
- void updateLayoutTreeIgnorePendingStylesheets();
- void updateLayoutTreeForNode(const Node*);
- void updateLayout();
+ void updateStyleAndLayoutTree();
+ // Same as updateStyleAndLayoutTree() except ignoring pending stylesheets.
+ void updateStyleAndLayoutTreeIgnorePendingStylesheets();
+ void updateStyleAndLayoutTreeForNode(const Node*);
+ void updateStyleAndLayout();
void layoutUpdated();
enum RunPostLayoutTasks {
RunPostLayoutTasksAsyhnchronously,
RunPostLayoutTasksSynchronously,
};
- void updateLayoutIgnorePendingStylesheets(RunPostLayoutTasks = RunPostLayoutTasksAsyhnchronously);
- void updateLayoutIgnorePendingStylesheetsForNode(Node*);
+ void updateStyleAndLayoutIgnorePendingStylesheets(RunPostLayoutTasks = RunPostLayoutTasksAsyhnchronously);
+ void updateStyleAndLayoutIgnorePendingStylesheetsForNode(Node*);
PassRefPtr<ComputedStyle> styleForElementIgnoringPendingStylesheets(Element*);
PassRefPtr<ComputedStyle> styleForPage(int pageIndex);

Powered by Google App Engine
This is Rietveld 408576698